
module rsu_quartus_top (
	input refclk_50
	);
   
//************************************************
// Set HW_VERSION parameter to different values
// for the factory and application images.

	localparam HW_VERSION = 32'h13062511;
	
//************************************************

//------------------------------------------------
// MAIN PLL:
// Input Clock: 50 MHz (Board osc.)
// C0 = 25MHz
// C1 = 100MHz
//------------------------------------------------

   wire 		clk_25_clk;
   wire 		sys_clk;
   wire 		pll_main_lock;
   
   pll_civ pll_inst (
	       // CLOCK
	       .inclk0         (refclk_50),
	       .areset           (!pll_reset_n),
	       .c0               (clk_25_clk), // 25 MHz
	       .c1               (sys_clk),    // 100 MHz
	       .locked           (pll_main_lock)
	       );
//------------------------------------------------


	// Generate reset to PLL
   reg [8:0] 				     reset_counter;

   always @(posedge refclk_50)
     if (!(&reset_counter))
       reset_counter <= reset_counter + 1'b1;     

   wire   pll_reset_n = &reset_counter;


   // *************************
   // * CLK25 RESET (25 MHz)
   // *************************
   reg [1:0] sync_clk25_rst_n;
   
   always @ (posedge clk_25_clk or negedge pll_main_lock)
     if (!pll_main_lock) 
			sync_clk25_rst_n	<= 2'b0;
     else 
			sync_clk25_rst_n	<= {sync_clk25_rst_n[0], 1'b1};
   
	wire   clk25_rst_n = sync_clk25_rst_n[1];

   // *************************
   // * SYS_CLK RESET (100 MHz)
   // *************************
   reg [1:0] sync_sys_rst_n;
   
   always @ (posedge sys_clk or negedge pll_main_lock)
     if (!pll_main_lock) 
			sync_sys_rst_n	<= 2'b0;
     else 
			sync_sys_rst_n	<= {sync_sys_rst_n[0], 1'b1};
        
	wire   sys_rst_n = sync_sys_rst_n[1];

   rsu_example u0 (
	  .sys_reset_n_reset_n   (sys_rst_n),             // sys_reset_n.reset_n
	  .sys_clk_clk           (sys_clk),               // sys_clk.clk
	  .clk_25_clk            (clk_25_clk),            // clk_25.clk
	  .rst_25_n_reset_n      (clk25_rst_n),           // rst_25_n.reset_n
	  .hw_version_pio_export (HW_VERSION)             // hw_version_pio.export
  );

  sfl sfl_inst (
   .noe_in    (1'b0)
	);
	 
endmodule 

