# Base addresses from Qsys system
set RSU_Base 0x00000000
set HW_VerAddr 0x00000100

# Addresses within RSU component for accessing Reconfig Source, AI Boot Addr and AnF Bit.
# Shift left by 2 in order to accomodate byte vs word addressing through System Console.
set ReconfigSrcAddr [expr $RSU_Base + [expr 0x0 << 2]]
set BootAddrAddr    [expr $RSU_Base + [expr 0x4 << 2]]
set AnF_Addr        [expr $RSU_Base + [expr 0x5 << 2]]
puts [concat "RSU Base: " [format {%08x} $RSU_Base]]
puts [concat "Boot Address Addr: " [format {%08x} $BootAddrAddr]]
puts [concat "AnF Addr: " [format {%08x} $AnF_Addr]]

puts "\n"

# Open the 1st master in the system - Should be the JTAG-to-Avalon Master
set m [ lindex [ get_service_paths master ] 0 ]
open_service master $m

# Read HWVERSION
set HW_ver [master_read_32 $m $HW_VerAddr 1]
puts [concat "HW Version:" $HW_ver]

# Read Reconfiguration Source
set ReconfigSourceRead [master_read_32 $m $ReconfigSrcAddr 1]
puts [concat "Reconfig Source:" $ReconfigSourceRead]

# Read back boot address
set BootAddrReadBack [master_read_32 $m $BootAddrAddr 1]
puts [concat "Read Back Boot Address:" $BootAddrReadBack]

puts "\n"

# Read back AnF
set AnF_BitReadBack [master_read_32 $m $AnF_Addr 1]
puts [concat "Read Back AnF Bit:" $AnF_BitReadBack]

