# Base addresses from Qsys system
set RSU_Base 0x00000000
set HW_VerAddr 0x00000100

# Addresses within RSU component for accessing MSM Application registers.
# Shift left by 2 in order to accomodate byte vs word addressing through System Console.

# **** All addresses below are used for MSM Mode APPLICATION ****

# Reconfig control address is address[5] and goes directly to the reconfig signal of 
# the alremote_update_cyclone4 function in rsu_cyclone4.v.  read_source and param are not used when
# writing the reconfig port of the altremote_update_cyclone4 function.
set ReconfigCtrlAddr [expr $RSU_Base + [expr 0x20 << 2]]

# Read Master State Machine Current State read_source = 00b; param = 000b;
set RdMstrStMachCurrStMdAddr  [expr $RSU_Base + [expr 0x0  << 2]]

# Read current application mode watchdog value read_source = 01b; param = 010b;
set RdCuAppMdWdogValAddr  [expr $RSU_Base + [expr 0xA  << 2]]

# Read current application mode watchdog enable read_source = 01b; param = 011b;
set RdCuAppMdWdogEnAddr  [expr $RSU_Base + [expr 0xB  << 2]]

# Read current application mode boot address read_source = 10b; param = 100b;
set RdCuAppMdBootAddr  [expr $RSU_Base + [expr 0x14  << 2]]

puts [concat "RSU Base: " [format {%08x} $RSU_Base]]
puts [concat "Read current application mode watchdog value address: " [format {%08x} $RdCuAppMdWdogValAddr]]
puts [concat "Read current application mode watchdog enable address: " [format {%08x} $RdCuAppMdWdogEnAddr]]
puts [concat "Read current application mode boot address: " [format {%08x} $RdCuAppMdBootAddr]]

puts "\n"

# Open the 1st master in the system - Should be the JTAG-to-Avalon Master
set m [ lindex [ get_service_paths master ] 0 ]
open_service master $m

# Read HWVERSION
set HW_ver [master_read_32 $m $HW_VerAddr 1]
puts [concat "HW Version:" $HW_ver]

# Read Master State Machine Current State Mode
set RdMstrStMachCurrStMd [master_read_32 $m $RdMstrStMachCurrStMdAddr 1]
puts [concat "Master State Machine (MSM) Current State Mode:" $RdMstrStMachCurrStMd]

# Read current application mode watchdog value
set RdCuAppMdWdogVal [master_read_32 $m $RdCuAppMdWdogValAddr 1]
puts [concat "Current application mode watchdog value:" $RdCuAppMdWdogVal]

# Read current application mode watchdog enable
set RdCuAppMdWdogEn [master_read_32 $m $RdCuAppMdWdogEnAddr 1]
puts [concat "Current application mode watchdog enable:" $RdCuAppMdWdogEn]

# Read current application mode boot address
set RdCuAppMdBoot [master_read_32 $m $RdCuAppMdBootAddr 1]
puts [concat "Current application mode boot address:" $RdCuAppMdBoot]

# Write RECONFIG to go back to factory image
#puts [concat "Writing Reconfig Bit..."]
#master_write_32 $m $ReconfigCtrlAddr 0x1

puts "\n"


